pub enum AbilityCostStep {
RestOther,
SacrificeFromStage,
DiscardFromHand,
ClockFromHand,
ClockFromDeckTop,
RevealFromHand,
}Expand description
Cost requirements for an activated ability.
Variants
RestOther
Rest another character as part of the activation cost.
SacrificeFromStage
Put a character from stage into waiting room as part of the activation cost.
DiscardFromHand
Discard a card from hand as part of the activation cost.
ClockFromHand
Clock a card from hand as part of the activation cost.
ClockFromDeckTop
Clock the top card(s) of the deck as part of the activation cost.
RevealFromHand
Reveal a card from hand as part of the activation cost.