pub enum BrainstormMode {
Draw,
SalvageCharacter,
LookTopToHand,
LookTopToHandThenDiscard,
SalvageCharacterThenDiscard,
}Expand description
Brainstorm payoff mode.
Variants
Draw
Draw a card for each climax revealed.
SalvageCharacter
Salvage a character for each climax revealed.
LookTopToHand
Look at the top cards and move eligible cards to hand.
LookTopToHandThenDiscard
Look at the top cards, move eligible cards to hand, then discard.
SalvageCharacterThenDiscard
Salvage characters, then discard.