pub enum CountCmp {
AtLeast,
AtMost,
}Expand description
Comparison operator for count-based conditions.
Variants
AtLeast
Count must be greater than or equal to the threshold.
AtMost
Count must be less than or equal to the threshold.