pub struct AbilityCost {
pub stock: u8,
pub rest_self: bool,
pub rest_other: u8,
pub sacrifice_from_stage: u8,
pub discard_from_hand: u8,
pub clock_from_hand: u8,
pub clock_from_deck_top: u8,
pub reveal_from_hand: u8,
pub move_self_to_waiting_room: bool,
pub return_self_to_hand: bool,
pub step_order: Vec<AbilityCostStep>,
}Expand description
Cost requirements for an activated ability.
Fields
stock: u8Stock cost to pay.
rest_self: boolWhether the source must rest itself.
rest_other: u8Number of other characters to rest.
sacrifice_from_stage: u8Characters to put from stage into waiting room as cost.
discard_from_hand: u8Cards to discard from hand.
clock_from_hand: u8Cards to clock from hand.
clock_from_deck_top: u8Cards to clock from top of deck.
reveal_from_hand: u8Cards to reveal from hand.
move_self_to_waiting_room: boolWhether the source card must be put into waiting room as cost.
return_self_to_hand: boolWhether the source card must be returned to hand as cost.
step_order: Vec<AbilityCostStep>Optional explicit ordering for staged cost steps.
Implementations
Sourceimpl AbilityCost
impl AbilityCost
Sourcepub fn next_explicit_step(&self) -> Option<CostStepKind>
pub fn next_explicit_step(&self) -> Option<CostStepKind>
Return the next pending staged step in explicit order, if any.