pub fn build_action_mask(
actions: &[ActionDesc],
) -> (Vec<u8>, Vec<Option<ActionDesc>>)Expand description
Build a dense action mask and lookup table from a legal action list.
pub fn build_action_mask(
actions: &[ActionDesc],
) -> (Vec<u8>, Vec<Option<ActionDesc>>)Build a dense action mask and lookup table from a legal action list.