pub enum ActionError {
NoPendingDecision,
InvalidActionId {
action_id: usize,
},
ActionNotLegal,
}Expand description
Stable error categories for action application.
Variants
NoPendingDecision
An action was attempted when no decision is pending.
InvalidActionId
An action id could not be decoded or is outside the action space.
ActionNotLegal
An action id was decoded but is not legal for the current decision.