pub enum ConfigError {
DeckLength {
player: u8,
got: usize,
expected: usize,
},
UnknownCardId {
player: u8,
card_id: CardId,
},
ClimaxCount {
player: u8,
got: usize,
max: usize,
},
CardCopyCount {
player: u8,
card_id: CardId,
got: usize,
max: usize,
},
}Expand description
Stable error categories for environment configuration validation.
Variants
DeckLength
A player’s deck length did not match the expected size.
Fields
UnknownCardId
A player’s deck referenced a card id that is not present in the database.
ClimaxCount
A player’s deck contained too many climax cards.
Fields
CardCopyCount
A player’s deck contained too many copies of a single card id.