pub fn can_declare_attack(
state: &GameState,
player: u8,
slot: u8,
attack_type: AttackType,
curriculum: &CurriculumConfig,
) -> Result<(), &'static str>Expand description
Validate whether an attack can be declared from a slot.
pub fn can_declare_attack(
state: &GameState,
player: u8,
slot: u8,
attack_type: AttackType,
curriculum: &CurriculumConfig,
) -> Result<(), &'static str>Validate whether an attack can be declared from a slot.