AttackContext

Struct AttackContext 

pub struct AttackContext {
Show 22 fields pub attacker_slot: u8, pub defender_slot: Option<u8>, pub attack_type: AttackType, pub trigger_card: Option<CardId>, pub trigger_instance_id: Option<CardInstanceId>, pub trigger_checks_total: u8, pub trigger_checks_resolved: u8, pub damage: i32, pub counter_allowed: bool, pub counter_played: bool, pub counter_power: i32, pub damage_modifiers: Vec<DamageModifier>, pub pending_shot_damage: u8, pub next_modifier_id: u32, pub last_damage_event_id: Option<u32>, pub auto_trigger_enqueued: bool, pub auto_damage_enqueued: bool, pub battle_damage_applied: bool, pub step: AttackStep, pub decl_window_done: bool, pub trigger_window_done: bool, pub damage_window_done: bool,
}
Context for an ongoing attack.

Fields

attacker_slot: u8

Attacker stage slot index.

defender_slot: Option<u8>

Optional defender stage slot index (None for direct attacks).

attack_type: AttackType

Declared attack type.

trigger_card: Option<CardId>

Trigger-check revealed card id (if any).

trigger_instance_id: Option<CardInstanceId>

Trigger-check revealed card instance id (if any).

trigger_checks_total: u8

Total trigger checks required.

trigger_checks_resolved: u8

Trigger checks already resolved.

damage: i32

Current damage amount.

counter_allowed: bool

Whether counter is allowed.

counter_played: bool

Whether a counter was played.

counter_power: i32

Power added by counters.

damage_modifiers: Vec<DamageModifier>

Active damage modifiers.

pending_shot_damage: u8

Pending shot damage remaining to apply.

next_modifier_id: u32

Next id for damage modifier instances within this attack.

last_damage_event_id: Option<u32>

Last damage event id emitted for this attack (if any).

auto_trigger_enqueued: bool

Whether auto triggers were enqueued for this attack.

auto_damage_enqueued: bool

Whether auto damage effects were enqueued for this attack.

battle_damage_applied: bool

Whether battle damage has been applied.

step: AttackStep

Current sub-step within the attack.

decl_window_done: bool

Whether the declaration timing window is complete.

trigger_window_done: bool

Whether the trigger timing window is complete.

damage_window_done: bool

Whether the damage timing window is complete.