pub enum ActionDesc {
Show 19 variants
MulliganConfirm,
MulliganSelect {
hand_index: u8,
},
Pass,
Clock {
hand_index: u8,
},
MainPlayCharacter {
hand_index: u8,
stage_slot: u8,
},
MainPlayEvent {
hand_index: u8,
},
MainMove {
from_slot: u8,
to_slot: u8,
},
MainActivateAbility {
slot: u8,
ability_index: u8,
},
ClimaxPlay {
hand_index: u8,
},
Attack {
slot: u8,
attack_type: AttackType,
},
CounterPlay {
hand_index: u8,
},
LevelUp {
index: u8,
},
EncorePay {
slot: u8,
},
EncoreDecline {
slot: u8,
},
TriggerOrder {
index: u8,
},
ChoiceSelect {
index: u8,
},
ChoicePrevPage,
ChoiceNextPage,
Concede,
}Expand description
Canonical action descriptor used as the truth representation of legal actions.
Variants
MulliganConfirm
Confirm mulligan without selecting additional cards.
MulliganSelect
Select a hand card for mulligan.
Pass
Pass the current decision.
Clock
Clock a hand card.
MainPlayCharacter
Play a character from hand to a stage slot.
Fields
MainPlayEvent
Play an event from hand.
MainMove
Move a character between stage slots.
Fields
MainActivateAbility
Activate a character ability from a stage slot.
Fields
ClimaxPlay
Play a climax from hand.
Attack
Declare an attack from a stage slot.
CounterPlay
Play a counter from hand.
LevelUp
Select a card for level up.
EncorePay
Pay encore for a character.
EncoreDecline
Decline encore for a character.
TriggerOrder
Select trigger order index.
ChoiceSelect
Select a choice option by index.
ChoicePrevPage
Page to previous choice options.
ChoiceNextPage
Page to next choice options.
Concede
Concede the game.